@@ -11,7 +11,7 @@ use Carp;
 use JSON::XS;
 use URI;    # The GET requests need URI-escaping
 
-our $VERSION = '0.03_01';
+our $VERSION = '0.03_02';
 
 sub new {
 	my ($class, %opts) = @_;
@@ -112,7 +112,21 @@ sub check {
 	require WebService::AbuseIPDB::CheckResponse;
 	return WebService::AbuseIPDB::CheckResponse->new (
 		$self->_send_receive ('GET', 'check', $data));
+}
 
+sub check_block {
+	my ($self, %args) = @_;
+	unless (exists $args{ip}) {
+		carp "No IP in argument hash";
+		return;
+	}
+
+	# Validate this here TODO
+	my $data = {network => $args{ip}};
+	$data->{maxAgeInDays} = $args{max_age} if exists $args{max_age};
+	require WebService::AbuseIPDB::CheckBlockResponse;
+	return WebService::AbuseIPDB::CheckBlockResponse->new (
+		$self->_send_receive ('GET', 'check-block', $data));
 }
 
 sub report {
@@ -285,6 +299,31 @@ B<Not yet impelemented>.
 
 =back
 
+
+=head2 check_block
+
+    my $res = $ipdb->check_block (ip => '127.0.0.0/29', max_age => 30);
+
+This uses the C<check-block> endpoint and returns a
+L<WebService::AbuseIPDB::CheckBlockResponse> object to access the data held
+in the database for the provided IP address range. The argument is a hash with
+these keys:
+
+=over
+
+=item ip
+
+The IP range to be checked in
+L<CIDR|https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing>
+format. This item is mandatory.
+
+=item max_age
+
+The age in integral days of the oldest report(s) to include. If
+omitted the server default is used (currently 30).
+
+=back
+
 =head2 report
 
     my $res = $ipdb->report (
@@ -362,7 +401,7 @@ the interface are liable to change.
 
 Implement the C<verbose> option on the check method.
 
-Add the other API endpoints: check-block and bulk-report. Allow for fast
+Add the bulk-report API endpoints. Allow for fast
 blacklist-as-string response too.
 
 More validation/sanitation of inputs.
@@ -384,8 +423,10 @@ Pete Houston, C<< <cpan at openstrike.co.uk> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-webservice-abuseipdb at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WebService-AbuseIPDB>.  See the file CONTRIBUTING.md for further details.
+Please report any bugs or feature requests to
+C<bug-webservice-abuseipdb at rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WebService-AbuseIPDB>.
+See the file CONTRIBUTING.md for further details.
 
 =head1 ACKNOWLEDGEMENTS
 
